nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Oscctla

Struct Oscctla 

#[repr(transparent)]
pub struct Oscctla(pub u32);
Oscillator Control A

Tuple Fields

0: u32

Implementations

Source

impl Oscctla

pub const fn osc_en(&self) -> bool

Crystal Oscillator Enable

pub const fn set_osc_en(&mut self, val: bool)

Crystal Oscillator Enable

pub const fn osc_byp_en(&self) -> bool

Crystal Oscillator Bypass Enable

pub const fn set_osc_byp_en(&mut self, val: bool)

Crystal Oscillator Bypass Enable

pub const fn coarse_amp_gain(&self) -> CoarseAmpGain

Amplifier gain adjustment bits to allow the use of a wide range of external crystal ESR values See the device datasheet for the ranges supported by this device

pub const fn set_coarse_amp_gain(&mut self, val: CoarseAmpGain)

Amplifier gain adjustment bits to allow the use of a wide range of external crystal ESR values See the device datasheet for the ranges supported by this device

pub const fn cap_sel_en(&self) -> bool

Crystal Load Capacitance Selection Enable

pub const fn set_cap_sel_en(&mut self, val: bool)

Crystal Load Capacitance Selection Enable

pub const fn extal_cap_sel(&self) -> ExtalCapSel

Crystal Load Capacitance Selection

pub const fn set_extal_cap_sel(&mut self, val: ExtalCapSel)

Crystal Load Capacitance Selection

pub const fn xtal_cap_sel(&self) -> XtalCapSel

Crystal Load Capacitance Selection

pub const fn set_xtal_cap_sel(&mut self, val: XtalCapSel)

Crystal Load Capacitance Selection

pub const fn mode_en(&self) -> ModeEn

Mode Enable

pub const fn set_mode_en(&mut self, val: ModeEn)

Mode Enable

pub const fn supply_det(&self) -> SupplyDet

Supply Detector Trim

pub const fn set_supply_det(&mut self, val: SupplyDet)

Supply Detector Trim