#[repr(transparent)]pub struct Oscctla(pub u32);Expand description
Oscillator Control A
Tuple Fields
0: u32Implementations
Sourceimpl Oscctla
impl Oscctla
Sourcepub const fn set_osc_en(&mut self, val: bool)
pub const fn set_osc_en(&mut self, val: bool)
Crystal Oscillator Enable
Sourcepub const fn osc_byp_en(&self) -> bool
pub const fn osc_byp_en(&self) -> bool
Crystal Oscillator Bypass Enable
Sourcepub const fn set_osc_byp_en(&mut self, val: bool)
pub const fn set_osc_byp_en(&mut self, val: bool)
Crystal Oscillator Bypass Enable
Sourcepub const fn coarse_amp_gain(&self) -> CoarseAmpGain
pub const fn coarse_amp_gain(&self) -> CoarseAmpGain
Amplifier gain adjustment bits to allow the use of a wide range of external crystal ESR values See the device datasheet for the ranges supported by this device
Sourcepub const fn set_coarse_amp_gain(&mut self, val: CoarseAmpGain)
pub const fn set_coarse_amp_gain(&mut self, val: CoarseAmpGain)
Amplifier gain adjustment bits to allow the use of a wide range of external crystal ESR values See the device datasheet for the ranges supported by this device
Sourcepub const fn cap_sel_en(&self) -> bool
pub const fn cap_sel_en(&self) -> bool
Crystal Load Capacitance Selection Enable
Sourcepub const fn set_cap_sel_en(&mut self, val: bool)
pub const fn set_cap_sel_en(&mut self, val: bool)
Crystal Load Capacitance Selection Enable
Sourcepub const fn extal_cap_sel(&self) -> ExtalCapSel
pub const fn extal_cap_sel(&self) -> ExtalCapSel
Crystal Load Capacitance Selection
Sourcepub const fn set_extal_cap_sel(&mut self, val: ExtalCapSel)
pub const fn set_extal_cap_sel(&mut self, val: ExtalCapSel)
Crystal Load Capacitance Selection
Sourcepub const fn xtal_cap_sel(&self) -> XtalCapSel
pub const fn xtal_cap_sel(&self) -> XtalCapSel
Crystal Load Capacitance Selection
Sourcepub const fn set_xtal_cap_sel(&mut self, val: XtalCapSel)
pub const fn set_xtal_cap_sel(&mut self, val: XtalCapSel)
Crystal Load Capacitance Selection
Sourcepub const fn set_mode_en(&mut self, val: ModeEn)
pub const fn set_mode_en(&mut self, val: ModeEn)
Mode Enable
Sourcepub const fn supply_det(&self) -> SupplyDet
pub const fn supply_det(&self) -> SupplyDet
Supply Detector Trim
Sourcepub const fn set_supply_det(&mut self, val: SupplyDet)
pub const fn set_supply_det(&mut self, val: SupplyDet)
Supply Detector Trim